"""Patch for https://bugs.launchpad.net/zope2/+bug/740831."""
from logging import getLogger
logger = getLogger(__name__)


def supports_retry(self):
  if getattr(self.response, "_streaming", False):
    # we try to retry a request whose response has already (at least partially)
    # been written -- this leads to desaster (wrong responses to subsequents
    # requests). Prevent it.
    logger.error("prevent request retry for which part of its response has already been written")
    return False
  return self._dm_ori_supports_retry()
     

# patch HTTPResponse
from ZPublisher.HTTPRequest import HTTPRequest

HTTPRequest._dm_ori_supports_retry = HTTPRequest.supports_retry
HTTPRequest.supports_retry = supports_retry

logger.info("ZPublisher.HTTPRequest.supports_retry patched.")




from os.path import abspath, dirname, join
try:
  # try to use setuptools
  from setuptools import setup
  setupArgs = dict(
      include_package_data=True,
      namespace_packages=['dm', 'dm.zopepatches'],
      zip_safe=False,
      entry_points = dict(
        ),
      )
except ImportError:
  # use distutils
  from distutils import setup
  setupArgs = dict(
    )

cd = abspath(dirname(__file__))
pd = join(cd, 'dm', 'zopepatches', 'fix_responsewrite_conflict')

def pread(filename, base=pd): return open(join(base, filename)).read().rstrip()

setup(name='dm.zopepatches.fix_responsewrite_conflict',
      version=pread('VERSION.txt').split('\n')[0],
      description="Zope[2] patch to alleviate the effect of https://bugs.launchpad.net/zope2/+bug/740831.",
      long_description=pread('README.txt'),
      classifiers=[
#        'Development Status :: 3 - Alpha',
       'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Framework :: Zope2',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities',
        ],
      author='Dieter Maurer',
      author_email='dieter@handshake.de',
      url='http://pypi.python.org/pypi/dm.zopepatches.fix_responsewrite_conflict',
      packages=['dm', 'dm.zopepatches', 'dm.zopepatches.fix_responsewrite_conflict'],
      keywords='patch wrong response Zope2',
      license='BSD',
      **setupArgs
      )
